@@ -1417,7 +1417,8 @@ class AppHandler(object):
             return ""
         return pretty_hours(datetime.timedelta(seconds=seconds))
 
-    def render_percent(self, value, places=2, **kwargs):
+    def render_percent(self, value, places=2, from_decimal=False,
+                       **kwargs):
         """
         Render a human-friendly display string for the given
         percentage value.
@@ -1427,9 +1428,15 @@ class AppHandler(object):
 
         :param places: Number of decimal places to display in the
            rendered string.
+
+        :param from_decimal: If false (the default), then ``value``
+           should (normally) be between 0 - 100.  But if true, then
+           ``value`` is assumed to be between 0.0 and 1.0 instead.
         """
         fmt = '{{:0.{}f}} %'.format(places)
-        return fmt.format(value * 100)
+        if from_decimal:
+            value *= 100
+        return fmt.format(value)
 
     def send_email(self, key, data={}, **kwargs):
         """
