@@ -32,10 +32,10 @@ import warnings
 
 import sqlalchemy_continuum as continuum
 
-from rattail.app import GenericHandler
+from rattail.app import GenericHandler, MergeMixin
 
 
-class AuthHandler(GenericHandler):
+class AuthHandler(GenericHandler, MergeMixin):
     """
     Base class and default implementation for the so-called "auth"
     handler, by which we mean "authentication and authorization".
@@ -327,6 +327,68 @@ class AuthHandler(GenericHandler):
             session.add(user)
         return user
 
+    def get_merge_preview_fields(self, **kwargs):
+        """
+        Returns a sequence of fields which will be used during a merge
+        preview.
+        """
+        F = self.make_merge_field
+        return [
+            F('uuid'),
+            F('username'),
+            F('person_uuid', coalesce=True),
+            F('person_name', coalesce=True),
+            F('role_count'),    # coalesced manually
+            F('active', coalesce=True),
+            F('sent_message_count', additive=True),
+            F('received_message_count', additive=True),
+        ]
+
+    def get_merge_preview_data(self, user, **kwargs):
+        return {
+            'uuid': user.uuid,
+            'username': user.username,
+            'person_uuid': user.person_uuid,
+            'person_name': user.person.display_name if user.person else None,
+            '_roles': user.roles, # needed for final role count
+            'role_count': len(user.roles),
+            'active': user.active,
+            'sent_message_count': len(user.sent_messages),
+            'received_message_count': len(user._messages),
+        }
+
+    def get_merge_resulting_data(self, removing, keeping, **kwargs):
+        result = super(AuthHandler, self).get_merge_resulting_data(
+            removing, keeping, **kwargs)
+
+        # nb. must "manually" coalesce the role count
+        result['role_count'] = len(set(removing['_roles'] + keeping['_roles']))
+
+        return result
+
+    def why_not_merge(self, removing, keeping, **kwargs):
+
+        if removing.sent_messages:
+            return "Cannot (yet) remove a user who has sent messages"
+
+        if removing._messages:
+            return "Cannot (yet) remove a user who has received messages"
+
+        if removing._roles:
+            return "Cannot (yet) remove a user who is assigned to roles"
+
+    def merge_update_keeping_object(self, removing, keeping):
+        super(AuthHandler, self).merge_update_keeping_object(removing, keeping)
+        session = self.app.get_session(keeping)
+        model = self.model
+
+        # update any notes authored by old user, to reflect new user
+        notes = session.query(model.Note)\
+                       .filter(model.Note.created_by == removing)\
+                       .all()
+        for note in notes:
+            note.created_by = keeping
+
     def delete_user(self, user, **kwargs):
         """
         Delete the given user account.  Use with caution!  As this
