@@ -373,12 +373,14 @@ class LabelBatchHandler(BatchHandler):
             data['sale_starts'] = data['sale_start']
             data['sale_ends'] = data['sale_stop']
 
-            # TODO: this flag seems dubious; not sure how best to
-            # handle, but also not sure it's even useful.  in what
-            # case would we want to print "dynamic" data from product
-            # master when we have it all in the batch?
-            if not batch.static_prices:
-                data['product'] = row.product
+            # TODO: not sure what to make of this yet.  printing
+            # labels should not require a product i think, but it
+            # currently does (cf. CommandFormatter.format_labels).
+            # and then again it seems like it would be useful for some
+            # label formatters to leverage things from the product
+            # which aren't in the batch data.  so for now we just
+            # always pass it i guess.
+            data['product'] = row.product
 
             profile.labels.append((data, row.label_quantity))
 
