@@ -28,6 +28,7 @@ from __future__ import unicode_literals, absolute_import
 
 import os
 import decimal
+import logging
 
 from sqlalchemy import orm
 
@@ -36,6 +37,9 @@ from rattail.batch import BatchHandler
 from rattail.vendors.invoices import require_invoice_parser
 
 
+log = logging.getLogger(__name__)
+
+
 class VendorInvoiceHandler(BatchHandler):
     """
     Handler for vendor invoice batches.
@@ -74,7 +78,11 @@ class VendorInvoiceHandler(BatchHandler):
         vendor_handler = self.app.get_vendor_handler()
         parser.vendor = vendor_handler.get_vendor(session, parser.vendor_key)
         assert batch.vendor is parser.vendor
-        batch.invoice_date = parser.parse_invoice_date(path)
+        try:
+            batch.invoice_date = parser.parse_invoice_date(path)
+        except:
+            log.warning("failed to parse invoice date for file: %s", path,
+                        exc_info=True)
         self.setup_populate(batch, progress=progress)
 
         def append(row, i):
