@@ -27,6 +27,7 @@ DataSync Utilities
 from __future__ import unicode_literals, absolute_import
 
 import datetime
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -38,40 +39,40 @@ def get_lastrun_setting(config, watcher_key):
     """
     Retrieve the "last run" setting name for the given watcher key.
     """
-    return 'rattail.datasync.{}.watcher.lastrun'.format(watcher_key)
+    warnings.warn("get_lastrun_setting() function is deprecated; please use "
+                  "DatasyncHandler.get_watcher_lastrun_setting() method instead",
+                  DeprecationWarning, stacklevel=2)
+
+    app = config.get_app()
+    handler = app.get_datasync_handler()
+    return handler.get_watcher_lastrun_setting(watcher_key)
 
 
 def get_lastrun_timefmt(config):
     """
     Retrieve the "last run" time format.
     """
-    return '%Y-%m-%d %H:%M:%S'
+    warnings.warn("get_lastrun_timefmt() function is deprecated; please use "
+                  "DatasyncHandler.get_lastrun_timefmt() method instead",
+                  DeprecationWarning, stacklevel=2)
+
+    app = config.get_app()
+    handler = app.get_datasync_handler()
+    return handler.get_lastrun_timefmt()
 
 
-def get_lastrun(config, watcher_key, local=False, tzinfo=True, session=None):
+def get_lastrun(config, watcher_key, **kwargs):
     """
     Retrieve the "last run" time for the datasync watcher thread identifed by
     ``watcher_key``.
     """
+    warnings.warn("get_lastrun() function is deprecated; please use "
+                  "DatasyncHandler.get_watcher_lastrunrun() method instead",
+                  DeprecationWarning, stacklevel=2)
+
     app = config.get_app()
-    # the 'last run' value is maintained as UTC
-    lastrun_setting = get_lastrun_setting(config, watcher_key)
-    timefmt = get_lastrun_timefmt(config)
-
-    close = False
-    if not session:
-        session = app.make_session()
-        close = True
-    lastrun = app.get_setting(session, lastrun_setting)
-    if close:
-        session.close()
-
-    if lastrun:
-        lastrun = datetime.datetime.strptime(lastrun, timefmt)
-        if local:
-            return localtime(config, lastrun, from_utc=True, tzinfo=tzinfo)
-        else:
-            return make_utc(lastrun, tzinfo=tzinfo)
+    handler = app.get_datasync_handler()
+    return handler.get_watcher_lastrun(watcher_key, **kwargs)
 
 
 def make_dependency_sorter(model):
@@ -143,15 +144,18 @@ def purge_datasync_settings(config, session):
     to_delete = session.query(model.Setting)\
                        .filter(sa.or_(
                            model.Setting.name == 'rattail.datasync.watch',
+                           model.Setting.name == 'rattail.datasync.supervisor_process_name',
+                           model.Setting.name == 'rattail.datasync.use_profile_settings',
                            model.Setting.name == 'tailbone.datasync.restart',
                            model.Setting.name.like('rattail.datasync.%.watcher'),
                            model.Setting.name.like('rattail.datasync.%.watcher.db'),
                            model.Setting.name.like('rattail.datasync.%.watcher.delay'),
                            model.Setting.name.like('rattail.datasync.%.watcher.retry_attempts'),
                            model.Setting.name.like('rattail.datasync.%.watcher.retry_delay'),
+                           model.Setting.name.like('rattail.datasync.%.watcher.kwarg.%'),
                            model.Setting.name.like('rattail.datasync.%.consumers'),
                            model.Setting.name.like('rattail.datasync.%.consumers.runas'),
                            model.Setting.name.like('rattail.datasync.%.consumer.%')))\
                        .all()
     for setting in to_delete:
-        app.delete_setting(session, setting)
+        app.delete_setting(session, setting.name)
