@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -202,6 +202,11 @@ class BatchMixin(object):
         if self.params is not None:
             return self.params.get(key)
 
+    def has_param(self, key):
+        if self.params is not None:
+            return key in self.params
+        return False
+
     def set_param(self, key, value):
         # TODO: why must we reconstruct params each time instead of
         # just modifying in place?
