@@ -981,9 +981,11 @@ class ProductVolatile(Base):
     a cache, for sake of SQL access to the values.
     """)
 
-    true_margin = sa.Column(sa.Numeric(precision=8, scale=5), nullable=True, doc="""
-    "True" profit margin for the "regular" unit price vs. the "true" unit cost
-    (:attr:`true_cost`).
+    true_margin = sa.Column(sa.Numeric(precision=9, scale=5), nullable=True, doc="""
+    "True" profit margin for the "regular" unit price vs. the "true"
+    unit cost (:attr:`true_cost`).  This is expressed as a
+    human-friendly percentage value, e.g. ``37.5`` (instead of
+    ``0.375``) for 37.5% margin.
     """)
 
 
