@@ -373,7 +373,7 @@ class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
     """
-    default_subject = "Upgrade Failure"
+    default_subject = "Upgrade failure for ${system_title}"
 
     def sample_data(self, request):
         upgrade = Object(
@@ -384,12 +384,9 @@ class upgrade_failure(Email):
             exit_code=42,
         )
         return {
-            # TODO: first 3 args should be provided by some common logic instead...
-            'rattail_config': self.config,
-            'localtime': localtime,
-            'app_title': self.config.app_title(),
             'upgrade': upgrade,
             'upgrade_url': '#',
+            'system_title': self.config.app_title(),
         }
 
 
@@ -397,7 +394,7 @@ class upgrade_success(Email):
     """
     Sent when an app upgrade is performed successfully.
     """
-    default_subject = "Upgrade Success"
+    default_subject = "Upgrade success for ${system_title}"
 
     def sample_data(self, request):
         upgrade = Object(
@@ -408,12 +405,9 @@ class upgrade_success(Email):
             exit_code=0,
         )
         return {
-            # TODO: first 3 args should be provided by some common logic instead...
-            'rattail_config': self.config,
-            'localtime': localtime,
-            'app_title': self.config.app_title(),
             'upgrade': upgrade,
             'upgrade_url': '#',
+            'system_title': self.config.app_title(),
         }
 
 
@@ -430,5 +424,6 @@ class user_feedback(Email):
             'user_name': "Fred Flintstone",
             'referrer': request.route_url('home'),
             'client_ip': '127.0.0.1',
+            'please_reply_to': 'fred@mailinator.com',
             'message': "Hey there,\n\njust wondered what the heck was going on with this site?  It's crap.\n\nFred",
         }
