@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -172,6 +172,52 @@ CUSTORDER_ITEM_EVENT = OrderedDict([
 ])
 
 
+# WORKORDER_STATUS_CREATED                 = 1
+WORKORDER_STATUS_SUBMITTED               = 10
+WORKORDER_STATUS_RECEIVED                = 20
+WORKORDER_STATUS_PENDING_ESTIMATE        = 30
+WORKORDER_STATUS_WAITING_FOR_PARTS       = 40
+WORKORDER_STATUS_WORKING_ON_IT           = 50
+WORKORDER_STATUS_RELEASED                = 60
+WORKORDER_STATUS_DELIVERED               = 70
+WORKORDER_STATUS_CANCELED                = 99
+
+WORKORDER_STATUS = OrderedDict([
+    # (WORKORDER_STATUS_CREATED,           "created"),
+    (WORKORDER_STATUS_SUBMITTED,         "submitted by customer"),
+    (WORKORDER_STATUS_RECEIVED,          "received from customer"),
+    (WORKORDER_STATUS_PENDING_ESTIMATE,  "pending estimate approval"),
+    (WORKORDER_STATUS_WAITING_FOR_PARTS, "waiting for parts"),
+    (WORKORDER_STATUS_WORKING_ON_IT,     "working on it"),
+    (WORKORDER_STATUS_RELEASED,          "released"),
+    (WORKORDER_STATUS_DELIVERED,         "delivered"),
+    (WORKORDER_STATUS_CANCELED,          "canceled"),
+])
+
+
+# WORKORDER_EVENT_CREATED                 = 1
+WORKORDER_EVENT_SUBMITTED               = 10
+WORKORDER_EVENT_RECEIVED                = 20
+WORKORDER_EVENT_PENDING_ESTIMATE        = 30
+WORKORDER_EVENT_WAITING_FOR_PARTS       = 40
+WORKORDER_EVENT_WORKING_ON_IT           = 50
+WORKORDER_EVENT_RELEASED                = 60
+WORKORDER_EVENT_DELIVERED               = 70
+WORKORDER_EVENT_CANCELED                = 99
+
+WORKORDER_EVENT = OrderedDict([
+    # (WORKORDER_EVENT_CREATED,           "created"),
+    (WORKORDER_EVENT_SUBMITTED,         "submitted by customer"),
+    (WORKORDER_EVENT_RECEIVED,          "received from customer"),
+    (WORKORDER_EVENT_PENDING_ESTIMATE,  "pending estimate approval"),
+    (WORKORDER_EVENT_WAITING_FOR_PARTS, "waiting for parts"),
+    (WORKORDER_EVENT_WORKING_ON_IT,     "working on it"),
+    (WORKORDER_EVENT_RELEASED,          "released"),
+    (WORKORDER_EVENT_DELIVERED,         "delivered"),
+    (WORKORDER_EVENT_CANCELED,          "canceled"),
+])
+
+
 EMAIL_ATTEMPT_CREATED           = 0
 EMAIL_ATTEMPT_SUCCESS           = 1
 EMAIL_ATTEMPT_FAILURE           = 2
