@@ -195,7 +195,8 @@ class ExcelWriter(object):
     Base class for Excel writers.
     """
 
-    def __init__(self, path, fields, sheet_title=None, number_formats={}):
+    def __init__(self, path, fields, sheet_title=None, number_formats={},
+                 highlight_rows=True):
         """
         Constructor; opens an Excel workbook for writing.
         """
@@ -206,6 +207,16 @@ class ExcelWriter(object):
         if sheet_title:
             self.sheet.title = sheet_title
         self.number_formats = number_formats
+        self.highlight_rows = highlight_rows
+
+    def load_workbook(self, path, clear_sheet=False):
+        self.book = openpyxl.load_workbook(filename=path)
+        self.sheet = self.book.active
+
+        if clear_sheet:
+            # remove all non-header rows from the sheet
+            # TODO: make header row count configurable
+            self.sheet.delete_rows(2, self.sheet.max_row)
 
     def create_sheet(self, title):
         """
@@ -250,13 +261,14 @@ class ExcelWriter(object):
                     cell.number_format = self.number_formats[field]
 
         # apply row highlighting
-        if row % 2 == 0:
-            fill_even = PatternFill(patternType='solid',
-                                    fgColor='d9d9d9',
-                                    bgColor='d9d9d9')
-            for col, field in enumerate(self.fields, 1):
-                cell = self.sheet.cell(row=row, column=col)
-                cell.fill = fill_even
+        if self.highlight_rows:
+            if row % 2 == 0:
+                fill_even = PatternFill(patternType='solid',
+                                        fgColor='d9d9d9',
+                                        bgColor='d9d9d9')
+                for col, field in enumerate(self.fields, 1):
+                    cell = self.sheet.cell(row=row, column=col)
+                    cell.fill = fill_even
 
     def write_rows(self, rows, progress=None):
         """
