@@ -184,7 +184,7 @@ class LuigiHandler(GenericHandler):
         appdir = self.config.appdir()
         env = {
             'PYTHONPATH': appdir,
-            'RATTAIL_CONFIG_FILES': os.path.join(appdir, 'silent.conf'),
+            'RATTAIL_CONFIG_FILES': os.pathsep.join(self.config.files_read),
         }
 
         # build our command, which will vary per caller request.  by
@@ -198,7 +198,6 @@ class LuigiHandler(GenericHandler):
             # rattail overnight <task>
             cmd = [
                 '{}/bin/rattail'.format(sys.prefix),
-                '--config', '{}/silent.conf'.format(appdir),
                 '--no-versioning',
                 'overnight', '-k', task['key'],
                 '--date={}'.format(date),
@@ -226,7 +225,6 @@ class LuigiHandler(GenericHandler):
                 # invoke luigi directly
                 cmd = [
                     '{}/bin/luigi'.format(sys.prefix),
-                    '--logging-conf-file', 'logging.conf',
                     '--module', task['module'],
                     task['class_name'],
                     '--date={}'.format(date),
@@ -235,9 +233,9 @@ class LuigiHandler(GenericHandler):
             # rattail run-n-mail 'task command'
             cmd = [
                 os.path.join(sys.prefix, 'bin', 'rattail'),
-                '--config', os.path.join(appdir, 'silent.conf'),
                 '--no-versioning',
                 'run-n-mail',
+                '--keep-exit-code',
                 '--subject', "Overnight for {}: {}".format(date, task['key']),
                 shlex_join(cmd),
             ]
@@ -247,6 +245,7 @@ class LuigiHandler(GenericHandler):
                 cmd.append('--skip-if-empty')
 
         # log final command
+        log.debug("env is: %s", env)
         log.debug("launching command in subprocess: %s", cmd)
         if dry_run:
             log.debug("dry-run mode, so aborting")
@@ -262,8 +261,14 @@ class LuigiHandler(GenericHandler):
         except subprocess.CalledProcessError as error:
             log.warning("command failed with exit code %s!  output was:",
                         error.returncode)
-            log.warning(error.stderr.decode('utf_8'))
+            log.warning(error.output.decode('utf_8'))
             raise
+        else:
+            if wait and self.config.getbool('rattail.luigi',
+                                            'auto_record_last_date',
+                                            # TODO: default should be true
+                                            default=False):
+                self.record_overnight_last_date(task, date)
         finally:
             # nb. always change back to first dir, in case we're being
             # called by some long-running process, e.g. web app
