@@ -340,13 +340,13 @@ class ProductsHandler(GenericHandler, MergeMixin):
         if kwargs.get('lookup_vendor_code'): # pragma: no cover
             warnings.warn("`lookup_vendor_code` param is deprecated, "
                           "please include 'vendor_code' in `lookup_fields` "
-                          "instead", DeprecationWarning)
+                          "instead", DeprecationWarning, stacklevel=2)
             if 'vendor_code' not in lookup_fields:
                 lookup_fields.append('vendor_code')
         if kwargs.get('lookup_by_code'): # pragma: no cover
             warnings.warn("`lookup_by_code` param is deprecated, "
                           "please include 'alt_code' in `lookup_fields` "
-                          "instead", DeprecationWarning)
+                          "instead", DeprecationWarning, stacklevel=2)
             if 'alt_code' not in lookup_fields:
                 lookup_fields.append('alt_code')
 
