@@ -88,6 +88,16 @@ class tailbone_buefy_version(Setting):
     name = 'buefy_version'
 
 
+class tailbone_feedback_allows_reply(Setting):
+    """
+    When user leaves Feedback, should we show them the "Please email
+    me back" option?
+    """
+    namespace = 'tailbone'
+    name = 'feedback_allows_reply'
+    data_type = bool
+
+
 class tailbone_grid_default_pagesize(Setting):
     """
     Default page size for grids.
